@@ -117,7 +117,7 @@ projectExtent <- function(object, crs) {
 }
 
 
-.computeRes <- function(obj, crs, proj6) {
+.computeRes <- function(obj, crs) {
 
 	x <- xmin(obj) + 0.5 * (xmax(obj) - xmin(obj))
 	y <- ymin(obj) + 0.5 * (ymax(obj) - ymin(obj))
@@ -127,13 +127,9 @@ projectExtent <- function(object, crs) {
 	y1 <- y - 0.5 * res[2]
 	y2 <- y + 0.5 * res[2]
 	xy <- cbind(c(x1, x2, x, x), c(y, y, y1, y2))
-	fromcrs <- .getCRS(obj)
-	if (proj6) {
-		fromcrs <- wkt(fromcrs)
-	} else {
-		fromcrs <- proj4string(fromcrs)	
-	}
-	pXY <- .rawTransform(fromcrs, crs, xy)
+	#fromcrs <- .getCRS(obj)
+	fromsrs <- .getSRS(obj)
+	pXY <- .rawTransform(fromsrs, crs, xy)
 	
 #	out <- c((pXY[2,1] - pXY[1,1]), (pXY[4,2] - pXY[3,2]))
 	outex <- extent(pXY)
@@ -164,17 +160,11 @@ projectExtent <- function(object, crs) {
 
 projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE, over=FALSE, filename="", ...)  {
 
-	use_proj6 <- .useproj6()
-
-	projfrom <- .getCRS(from)
+	#projfrom <- .getCRS(from)
+	projfrom <- .getSRS(from)
 	if (is.na(projfrom)) { 
 		stop("input projection is NA") 
 	}
-	if (use_proj6) {
-		if (is.null(wkt(projfrom))) {
-			use_proj6 = FALSE
-		}
-	}
 	
 	lonlat <- isLonLat(projfrom)
 	
@@ -182,35 +172,15 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 		if (missing(crs)) {
 			stop("both 'to' and 'crs' arguments are missing.")
 		}
-		projto <- .getCRS(crs)
-		if (use_proj6) {
-			if (is.null(wkt(projto))) {
-				use_proj6 = FALSE
-			}
-		}
+		#projto <- .getCRS(crs)
+		projto <- .getSRS(crs)
 		#compareCRS(projfrom, projto)
-		if (use_proj6) {
-		#	if (rgdal::compare_CRS(projto, projfrom)["strict"]) {
-		#		warning("input and ouput crs are the same")
-		#		#return(from) 
-		#	}
-			projfrom <- wkt(projfrom)
-		} else {
-			if (proj4string(projto) == proj4string(projfrom)) {
-				warning("input and ouput crs are the same")
-			}
-			projfrom <- proj4string(projfrom)
-		}
 		to <- projectExtent(from, projto)
-		to@crs <- projto
+#		to@crs <- projto
+		to@srs <- projto
 
-		if (use_proj6) {
-			projto <- wkt(projto)
-		} else {
-			projto <- proj4string(projto)		
-		}
 		if (missing(res)) {
-			res <- .computeRes(from, projto, use_proj6)
+			res <- .computeRes(from, projto)
 		}
 		res(to) <- res
 
@@ -231,21 +201,11 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 		to <- extend(to, e)
 	} else {
 	
-		projto <-.getCRS(to)
-		if (is.na(projto)) { 
-			stop("output projection is NA") 
+#		projto <-.getCRS(to)
+		projto <- .getSRS(to)
+		if (is.na(projto) || (projto == "")) { 
+			stop("output projection is empty") 
 		} 
-		if (use_proj6) {
-		#	if (rgdal::compare_CRS(projto, projfrom)["strict"]) {
-		#		warning("input and ouput crs are the same")
-		#	}
-			projfrom <- wkt(projfrom)
-		} else {
-			if (proj4string(projto) == proj4string(projfrom)) {
-				warning("input and ouput crs are the same")
-			}
-			projfrom = proj4string(projfrom)
-		}
 		
 		e <- extent( projectExtent(from, projto) )
 		add <- min(10, min(dim(to)[1:2])/10) * max(raster::res(to))
@@ -260,24 +220,19 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 			e@ymax <- min(90, e@ymax)
 		}
 
-		if (use_proj6) {
-			projto <- wkt(projto)
-		} else {
-			projto <- proj4string(projto)
-		}
 	}
 	
 	methods::validObject(to)
-	methods::validObject(.getCRS((to)))
+#	methods::validObject(.getCRS((to)))
 
 	#if (identical(projfrom, projto)) {
 	#	warning('projections of "from" and "to" are the same')
 	#}	
-	if ((!use_proj6) & lonlat & over) {
-		projto_int <- paste(projto, "+over")
-	} else {
+#	if ((!use_proj6) & lonlat & over) {
+#		projto_int <- paste(projto, "+over")
+#	} else {
 		projto_int <- projto	
-	}
+#	}
 
 	if (alignOnly) {
 		to <- .getAlignedRaster(from, to)
